==> vokoscreen_2.0.16~beta.orig.tar.gz: vokoscreen-2.0.16-beta/language/vokoscreen_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Gửi mail video mới nhất</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Gửi mail đối với một hoặc các video được chọn</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Gửi</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Bạn đã tìm thấy video dưới dạng đính kèm</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Chọn một hoặc nhiều tập tin</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>is busy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Noborder</source>
        <translation>Không có đường viền</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Đường viền</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Đóng lại</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Toàn màn hình</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Cửa sổ</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Khu vực</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Phóng to</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Nhịp</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Mặc định</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Không ghi hình phần hiển thị của chuột</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Đường dẫn video</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Trình phát</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen sẽ được thu nhỏ khi phần ghi hình được tiến hành</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dừng lại</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tạm dừng</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Phát</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Gửi</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Thời gian ghi hình</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Kích thước tính bằng KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Kích cỡ màn hình khi ghi hình</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Định dạng</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Thiết lập cho khung hình mỗi giây</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Mở thư mục</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Đếm ngược</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Phát video mới nhất</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Gửi Video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Chọn một hoặc nhiều thiết bị</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Khung hình thực mỗi giây</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Thiết bị %1 hiện đang bận</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Thực hiện</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Trang chủ</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Danh sách email</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Hỗ trợ</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Nhà phát triển</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Khung ảnh</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Bản thử nghiệm openSUSE</translation>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation>Bản thử nghiệm Ubuntu</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Ủng hộ tài chính</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Chương trình dùng để ghi hình</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Chuyển ngữ</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Chọn webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.1.8~beta.orig.tar.gz: vokoscreen-2.1.8-beta/language/vokoscreen_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Thiết bị hiện đang bận</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Gửi mail video mới nhất</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Gửi mail đối với một hoặc các video được chọn</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Gửi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Bạn đã tìm thấy video dưới dạng đính kèm</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Chọn một hoặc nhiều tập tin</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Đường viền</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Đóng lại</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Thiết bị hiện đang bận</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Toàn màn hình</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Cửa sổ</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Khu vực</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Phóng to</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Nhịp</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Mặc định</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Không ghi hình phần hiển thị của chuột</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Đường dẫn video</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Trình phát</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen sẽ được thu nhỏ khi phần ghi hình được tiến hành</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dừng lại</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tạm dừng</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Phát</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Gửi</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Thời gian ghi hình</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Kích thước tính bằng KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Kích cỡ màn hình khi ghi hình</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Định dạng</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Thiết lập cho khung hình mỗi giây</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Mở thư mục</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Đếm ngược</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Phát video mới nhất</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Gửi Video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Chọn một hoặc nhiều thiết bị</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Khung hình thực mỗi giây</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Thực hiện</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Trang chủ</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Danh sách email</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Hỗ trợ</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Nhà phát triển</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Khung ảnh</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Ủng hộ tài chính</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Chương trình dùng để ghi hình</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Chuyển ngữ</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Chọn webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
